@@ -15,14 +15,14 @@ class DingDingPlugin(NotificationPlugin):
     """
     Sentry plugin to send error counts to DingDing.
     """
-    author = 'ansheng'
-    author_url = 'https://github.com/anshengme/sentry-dingding'
+    author = 'lcfevr'
+    author_url = 'https://github.com/lcfevr/sentry-dingding-feelys'
     version = sentry_dingding.VERSION
     description = 'Send error counts to DingDing.'
     resource_links = [
-        ('Source', 'https://github.com/anshengme/sentry-dingding'),
-        ('Bug Tracker', 'https://github.com/anshengme/sentry-dingding/issues'),
-        ('README', 'https://github.com/anshengme/sentry-dingding/blob/master/README.md'),
+        ('Source', 'https://github.com/lcfevr/sentry-dingding-feelys'),
+        ('Bug Tracker', 'https://github.com/lcfevr/sentry-dingding-feelys/issues'),
+        ('README', 'https://github.com/lcfevr/sentry-dingding-feelys/blob/master/README.md'),
     ]
 
     slug = 'DingDing'
@@ -50,40 +50,17 @@ class DingDingPlugin(NotificationPlugin):
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
         title = "New alert from {}".format(event.project.slug)
-        event_url = "{0}events/{1}/".format(group.get_absolute_url(), event.id)
-        url_arr = event_url.split('/')
-        print(url_arr)
-        issue_id = url_arr[url_arr.index('issues') + 1]
-        print(issue_id)
-        issue_data = requests.get(
-            "http://web-middle.ruibogyl.work/sentry/findIssueTargetUrl",
-            {"id": issue_id},
-            headers={}
-        )
-        print issue_data
-        # response = requests.get(
-        #     "http://web-middle.ruibogyl.work/sentry/getDingDingAssignee",
-        #     {"url": issue_data["data"]["url"]},
-        #     headers={}
-        # ).json()
-        # print response["data"]["phone"]
+
         data = {
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": "#### {title} \n > {message} \n [点击查看问题]({event_url}) \n ".format(
+                "text": u"#### {title} \n > {message} [href]({url})".format(
                     title=title,
                     message=event.message,
-                    event_url=event_url,
-                    # phone=response["data"]["phone"],
-                ),
-            },
-            # "at": {
-            #     "atMobiles": [
-            #         response["phone"]
-            #     ],
-            #     "isAtAll": False
-            # }
+                    url=u"{}events/{}/".format(group.get_absolute_url(), event.id),
+                )
+            }
         }
         requests.post(
             url=send_url,
